[Scummvm-cvs-logs] CVS: scummvm/sound flac.cpp,1.5,1.6 mixer.h,1.96,1.97 mp3.cpp,1.16,1.17 vorbis.cpp,1.20,1.21

Max Horn fingolfin at users.sourceforge.net
Wed Mar 9 10:13:55 CET 2005


Update of /cvsroot/scummvm/scummvm/sound
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv27444/sound

Modified Files:
	flac.cpp mixer.h mp3.cpp vorbis.cpp 
Log Message:
changing AudioDataType -> SoundType, so now the constant names match the name of the data type / the SoundMixer method names

Index: flac.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/sound/flac.cpp,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- flac.cpp	1 Jan 2005 16:09:22 -0000	1.5
+++ flac.cpp	9 Mar 2005 18:12:48 -0000	1.6
@@ -783,7 +783,7 @@
 			flac->setLastSample(0);
 
 		if (flac->seekAbsolute(static_cast<FLAC__uint64>(startFrame) * (info.sample_rate / 75))) {
-			mixer->playInputStream(SoundMixer::kMusicAudioDataType, handle, flac);
+			mixer->playInputStream(SoundMixer::kMusicSoundType, handle, flac);
 			return;
 		}
 		// startSample is beyond the existing Samples

Index: mp3.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/sound/mp3.cpp,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -d -r1.16 -r1.17
--- mp3.cpp	1 Jan 2005 16:09:23 -0000	1.16
+++ mp3.cpp	9 Mar 2005 18:12:48 -0000	1.17
@@ -380,7 +380,7 @@
 
 	// Play it
 	AudioStream *input = new MP3InputStream(_file, durationTime);
-	mixer->playInputStream(SoundMixer::kMusicAudioDataType, handle, input);
+	mixer->playInputStream(SoundMixer::kMusicSoundType, handle, input);
 }
 
 MP3TrackInfo::~MP3TrackInfo() {

Index: vorbis.cpp
===================================================================
RCS file: /cvsroot/scummvm/scummvm/sound/vorbis.cpp,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -d -r1.20 -r1.21
--- vorbis.cpp	1 Jan 2005 16:09:23 -0000	1.20
+++ vorbis.cpp	9 Mar 2005 18:12:48 -0000	1.21
@@ -178,7 +178,7 @@
 #endif
 
 	AudioStream *input = makeVorbisStream(&_ov_file, duration * ov_info(&_ov_file, -1)->rate / 75);
-	mixer->playInputStream(SoundMixer::kMusicAudioDataType, handle, input);
+	mixer->playInputStream(SoundMixer::kMusicSoundType, handle, input);
 }
 
 DigitalTrackInfo *getVorbisTrack(int track) {





More information about the Scummvm-git-logs mailing list
Index: mixer.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/sound/mixer.h,v
retrieving revision 1.96
retrieving revision 1.97
diff -u -d -r1.96 -r1.97
--- mixer.h	6 Feb 2005 20:35:06 -0000	1.96
+++ mixer.h	9 Mar 2005 18:12:48 -0000	1.97
@@ -71,11 +71,11 @@
 	};
 	
 	enum SoundType {
-		kPlainAudioDataType = 0,
+		kPlainSoundType = 0,
 
-		kMusicAudioDataType = 1,
-		kSFXAudioDataType = 2,
-		kSpeechAudioDataType = 3
+		kMusicSoundType = 1,
+		kSFXSoundType = 2,
+		kSpeechSoundType = 3
 	};
 	
 	enum {
@@ -126,7 +126,7 @@
 	 * is not limited to it. The premix stream is invoked by the mixer whenever
 	 * it needs to generate any data, before any other mixing takes place.
 	 */
-	void setupPremix(AudioStream *stream, SoundType type = kPlainAudioDataType);
+	void setupPremix(AudioStream *stream, SoundType type = kPlainSoundType);
 
 
 
@@ -140,7 +140,7 @@
 				void *sound, uint32 size, uint rate, byte flags,
 				int id = -1, byte volume = 255, int8 balance = 0,
 				uint32 loopStart = 0, uint32 loopEnd = 0,
-				SoundType type = kSFXAudioDataType);
+				SoundType type = kSFXSoundType);
 
 	/**
 	 * Start playing the given audio input stream.
@@ -245,7 +245,7 @@
 	/**
 	 * Check whether any channel of the given sound type is active.
 	 * For example, this can be used to check whether any SFX sound
 	 * is currently playing, by checking for type kSFXAudioDataType.
 	 *
 	 * @param  type the sound type to look for
 	 * @return true if any channels of the specified type are active.
@@ -245,7 +245,7 @@
 	 * Check whether any channel of the given sound type is active.
 	 * For example, this can be used to check whether any SFX sound
-	 * is currently playing, by checking for type kSFXAudioDataType.
+	 * is currently playing, by checking for type kSFXSoundType.
 	 *
 	 * @param  type the sound type to look for
